@@ -11,12 +11,14 @@ from django.apps import apps
 
 class BaseGetAllowedTypes(metaclass=ABCMeta):
     """include receiver types and notice types"""
-    def __init__(self, receiver_id) -> None:
+    def __init__(self, receiver_id, **kwargs) -> None:
         if not isinstance(receiver_id, int):
             raise TypeError('invalid type: receiver user id')
         self.receiver_id = receiver_id
         self.done_receiver_type = list()
         self.done_notice_type = list()
+        for key, value in kwargs.items():
+            setattr(self, key, value)
 
     @staticmethod
     def get_all_notice_type_names():
@@ -27,6 +29,12 @@ class BaseGetAllowedTypes(metaclass=ABCMeta):
         return dict(apps.get_model('notice.ReceiverType').objects.all().values_list('name', 'id'))
 
     @abstractmethod
-    def judge(self):
+    def judge_notice_receiver_types(self) -> tuple:
         pass
 
+    @abstractmethod
+    def judge_notice_types(self) -> tuple:
+        pass
+
+    def judge(self):
+        return self.judge_notice_receiver_types(), self.judge_notice_types()
